// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "display/mesh/Mesh.hpp"
#include "scene/SceneComponent.hpp"

namespace Dawn {
  class RenderPass {
    private:
      std::shared_ptr<Mesh> mesh;
      const enum MeshDrawMode drawMode;
      const int32_t indiceStart;
      const int32_t indiceCount;

    public:
      /**
       * Constructs a new RenderPass.
       * 
       * @param self Self component instance that is creating this render pass.
       * @param d The data to use for this render pass.
       * @param mesh The mesh to use for this render pass.
       * @param drawMode The draw mode to use for this render pass.
       * @param indiceStart The indice to start drawing from.
       * @param indiceCount The number of indices to draw.
       */
      RenderPass(
        SceneComponent &self,
        const std::shared_ptr<Mesh> mesh,
        const enum MeshDrawMode drawMode,
        const int32_t indiceStart,
        const int32_t indiceCount
      );

      /**
       * Draws the mesh for this render pass.
       */
      void draw();

      /**
       * Cleans up the render pass.
       */
      ~RenderPass();
  };
}